@@ -1,20 +1,19 @@
-rstudy <- function (n, model, param, SE){
-
+rstudy <- function(n, model, param, SE) {
   stopifnot(SE >= 0)
-  if (n == 0)
-    return (NULL)
+  if (n == 0) {
+    return(NULL)
+  }
 
-  if (model == "fixed"){
+  if (model == "fixed") {
     # fixed H0 / H1
     rr <- rnorm(n, param, SE)
-
   } else {
-    if (is.null(dim(param))){
+    if (is.null(dim(param))) {
       # random H0
       delta <- rnorm(n, 0, param)
     } else {
       # random H1
-      delta <- rnorm(n, param[,"d"], param[,"tau"])
+      delta <- rnorm(n, param[, "d"], param[, "tau"])
     }
     rr <- rnorm(n, delta, SE)
   }
